@@ -10,6 +10,7 @@ from multiprocessing.pool import ThreadPool
 
 import boto3
 from PIL import Image, ImageOps
+import requests
 from botocore.exceptions import ClientError
 from django.utils.text import slugify
 
@@ -231,45 +232,42 @@ def get_dataset_name(db, file_name):
     return res
 
 
-def upload_csv(path, project_id, tag):
-    # headers = {
-    #     'Content-Type': 'multipart/form-data; boundary=----WebKitFormBoundary0W2raMzzSKutrSDG',
-    #     'Accept': '*/*',
-    # }
-    # data = {
-    #     f"""$------WebKitFormBoundary0W2raMzzSKutrSDG\\r\\nContent-Disposition: form-data; name': '"file"; filename={file_name}\\r\\nContent-Type: text/csv\\r\\n\\r\\n\\r\\n------WebKitFormBoundary0W2raMzzSKutrSDG--\\r\\n"""
-    # }
-    file_name = os.path.basename(path)
-    multipart_form_data = {
-        'file': (file_name, open(path, 'rb')),
-        'action': (None, 'store'),
-        'path': (None, '/path1')
-    }
-    url = '/direct_uploads'
-    # headers = {'content-type': 'application/x-www-form-urlencoded'}
-    headers = {}
-    r = make_request(url, files=multipart_form_data, headers=headers)
-    generic_file_id = int(r.json()['data']['id'])
-    r = make_request(f'/projects/{project_id}')
-    dataset_id = r.json()['data']['attributes']['datasetId']
-    headers={'content-type': 'application/vnd.api+json', 'accept':'application/vnd.api+json'}
-
-    post_data = {
+def upload_csv(path, project_id, tag=None):
+    headers = {'content-type': 'application/vnd.api+json', 'accept': 'application/vnd.api+json'}
+    file_name = path.split('/')[-1]
+    pre_signed_url = json.loads(make_request(f"/presigned_uploads/presigned_url?file_name={file_name}", headers=headers).content.decode())
+    with open(path, 'rb') as file:
+        files = {'file': (path, file)}
+        s3_response = requests.post(pre_signed_url['url'], data=pre_signed_url['fields'], files=files)
+    s3_file_name = s3_response.headers['location'].split('/')[-1]
+    file_upload_payload = {
         "data": {
-            "type": "source_files",
+            "type": "generic_files",
             "attributes": {
-                "file": {
-                    "type": "GenericFile",
-                    "id": generic_file_id
-                },
-                "dataset": {
-                    "type": "datasets",
-                    "id": dataset_id
-                }
+                "fileName": f"{s3_file_name}",
+                "originalFilename": f"{file_name}"
             }
         }
     }
+    uploaded_file_response = make_request('/presigned_uploads', json=file_upload_payload, headers=headers)
+    source_file_id = json.loads(uploaded_file_response.content.decode())['data']['id']
+    dataset_response = make_request(f'/projects/{project_id}')
+    dataset_id = dataset_response.json()['data']['attributes']['datasetId']
+    source_file_payload = {
+      "data": {
+        "type": "source_files",
+        "attributes": {
+          "file": {
+            "type": "GenericFile",
+            "id": f"{source_file_id}"
+          },
+          "dataset": {
+            "type": "datasets",
+            "id": dataset_id
+          }
+        }
+      }
+    }
     if tag:
-        post_data['data']['attributes']['tag_name'] = tag
-    r = make_request('/source_files', headers=headers, json=post_data)
-
+        source_file_payload['data']['attributes']['tag_name'] = tag
+    make_request('/source_files', json=source_file_payload, headers=headers)
